@@ -31,6 +31,7 @@ my @json_data_methods = (
        organisasjonsnummer
        orgnr
        navn
+       oppdateringsid
     /,
     
     # dates
@@ -38,6 +39,10 @@ my @json_data_methods = (
        registreringsdatoEnhetsregisteret
        stiftelsesdato
        sisteInnsendteAarsregnskap
+       slettedato
+       oppstartsdato
+       dato
+       datoEierskifte
     /,
 
     # Org form, like AS etc.
@@ -62,12 +67,14 @@ my @json_data_methods = (
     # hashes with their own extra keys
     qw /
        forretningsadresse
+       beliggenhetsadresse
        postadresse
        institusjonellSektorkode
        naeringskode1
        naeringskode2
        naeringskode3
        links
+       _links
        orgform
     /,
 
@@ -96,9 +103,25 @@ sub map_json_entries {
     if ($json->{navn}) {
 	# single entry on the data array
 	push @aj, $json;
-	
+
+    } elsif ($json->{_embedded} && $json->{_embedded}->{enheter}) {
+	# multiple entries V2
+	push @aj, @{$json->{_embedded}->{enheter}};
+
+    } elsif ($json->{_embedded} && $json->{_embedded}->{underenheter}) {
+	# multiple entries V2
+	push @aj, @{$json->{_embedded}->{underenheter}};
+
+    } elsif ($json->{_embedded} && $json->{_embedded}->{oppdaterteEnheter}) {
+	# multiple updated entries V2
+	push @aj, @{$json->{_embedded}->{oppdaterteEnheter}};
+
+    } elsif ($json->{_embedded} && $json->{_embedded}->{oppdaterteUnderenheter}) {
+	# multiple updated entries V2
+	push @aj, @{$json->{_embedded}->{oppdaterteUnderenheter}};
+
     } elsif ($json->{data}) {
-	# multiple entries 
+	# multiple entries V1
 	push @aj, @{$json->{data}};
     }
     
@@ -115,11 +138,27 @@ sub map_json_entries {
 	$eo->orgnr($eo->organisasjonsnummer);  
 	push @ao, $eo;
     }
-    # Set next link page if more pages are present 
+    # Set next link page if more pages are present
+
     $self->next_page(undef);
-    foreach my $l (@{$json->{links}}) {
-	if ($l->{rel} eq 'next') {
-	    $self->next_page($l->{href});
+    
+    if ($json->{links}) {
+	# V1 entry
+	#print STDERR "V1 json entry: ", Dumper $json;
+	foreach my $l (@{$json->{links}}) {
+	    if ($l->{rel} eq 'next') {
+		$self->next_page($l->{href});
+	    }
+	}
+
+    } elsif ($json->{_links}) {
+
+	#print STDERR "V2 json entry: ", Dumper $json;
+	# V2 entry
+	if ($json->{_links}->{next}) {
+	    $self->next_page($json->{_links}->{next}->{href});
+	    #print STDERR "self entry: ", Dumper $self;
+	    #exit;
 	}
     }
     
