@@ -80,75 +80,80 @@ sub lookup {
     #$client_ip = undef;
     
     my $sock = IO::Socket::INET->new (
-	PeerAddr => $whois_server,
-	PeerPort => $whois_port,
-	Proto    => 'tcp',
-	Timeout => 10,
-	);
+        PeerAddr => $whois_server,
+        PeerPort => $whois_port,
+        Proto    => 'tcp',
+        Timeout => 10,
+        );
 
     unless($sock) {
-	$self->{errno} = $WHOIS_LOOKUP_ERR_NO_CONN;
-	#print STDERR "SOCK ERR: $!\n";
-	return $self;
+        $self->{errno} = $WHOIS_LOOKUP_ERR_NO_CONN;
+        #print STDERR "SOCK ERR: $!\n";
+        return $self;
     }
 
     $query = Encode::encode('UTF-8', $query);
     
     if ($client_ip) {
-	# Use the special -V option to identify the client IP
-	# for proper rate limiting purposes.
-	# Note that the ip address of the proxy itself
-	# must be registered by Norid for this to work properly, 
-	# if not, a referral error is returned.
-	print $sock "-V v0,$client_ip -c utf-8 $query\n";
+        # Use the special -V option to identify the client IP
+        # for proper rate limiting purposes.
+        # Note that the ip address of the proxy itself
+        # must be registered by Norid for this to work properly, 
+        # if not, a referral error is returned.
+        print $sock "-V v0,$client_ip -c utf-8 $query\n";
     } else {
-	print $sock "-c utf-8 $query\n";
+        print $sock "-c utf-8 $query\n";
     }
     
     # Read all answer lines into one long LF separated $text
     while ($line = <$sock>) {
-	$text .= $line;
-    }	
+        $text .= $line;
+    }   
     close $sock;
     $text = Encode::decode('UTF-8', $text);
 
+    #print STDERR "text: $text\n";
+    
     # Parse whois and map values into the self object.
     $self->_parse($text);
 
     if ($text =~ m/\nDomain Information\n/) {
-	# If a domain name, or a domain handle, is looked up,
-	# the whois server also returns also the holder info as a second block.
-	# The below code parses the domain and holder info and
-	# returns the data in separate objects.
-	#
+        
+        # If a domain name, or a domain handle, is looked up, the
+        # whois server may also return the holder info as a second
+        # block. The below code parses the domain and holder info and
+        # returns the data in separate objects.
+        #
+        
+        # Domain info is first block. Holder contact info is second
+        # block, but only if the full (but limited) registrarwhois
+        # service is used. Split the text and make two objects.
+        
+        my ($dmy, $dtxt, $htxt) = split ('NORID Handle', $text);
 
-	#print STDERR "DOMAIN INFO with holder contact info FOUND: $query\n";
-	
-	# Domain info is first block, holder contact info is second block,
-	# split the text and make two objects
-	
-	my ($dmy, $dtxt, $htxt) = split ('NORID Handle', $text);
+        my $holder_whois;
+        my $domain_whois = NOLookup::Whois::WhoisLookup->new;
 
-	my $domain_whois = NOLookup::Whois::WhoisLookup->new;
-	my $holder_whois = NOLookup::Whois::WhoisLookup->new;
+        #print STDERR "\n------\nparse domain text: '$dtxt'\n";
+        $domain_whois->_parse("\nNORID Handle" . $dtxt);
 
-	#print STDERR "\n------\nparse domain text: '$dtxt'\n";
-	$domain_whois->_parse("\nNORID Handle" . $dtxt);
+        if ($htxt) {
+            $holder_whois = NOLookup::Whois::WhoisLookup->new;
+            #print STDERR "\n------\nparse holder text: '$htxt'\n";
+            $holder_whois->_parse("\nNORID Handle" . $htxt);
+        }
+        #print STDERR "self  : ", Dumper $self;
+        #print STDERR "domain whois: ", Dumper $domain_whois;
+        #print STDERR "holder whois: ", Dumper $holder_whois if $holder_whois;
 
-	#print STDERR "\n------\nparse holder text: '$htxt'\n";
-	$holder_whois->_parse("\nNORID Handle" . $htxt);
-	
-	#print STDERR "self  : ", Dumper $self;
-	#print STDERR "domain whois: ", Dumper $domain_whois;
-	#print STDERR "holder whois: ", Dumper $holder_whois;
+        return $self, $domain_whois, $holder_whois;
 
-	return $self, $domain_whois, $holder_whois;
     } 
 
     if ($text =~ m/\nHosts matching the search parameter\n/) {
-	# Set a method telling that a name_server_list is found,
-	# which is only the case when a host name is looked up.
-	$self->{name_server_list} = 1;
+        # Set a method telling that a name_server_list is found,
+        # which is only the case when a host name is looked up.
+        $self->{name_server_list} = 1;
     }
 
     #print STDERR "\n\n====\nself after $query: ", Dumper $self;
@@ -159,63 +164,63 @@ sub _parse {
     my ($self, $text)=@_;
 
     foreach my $line (split("\n",$text)) {
-	# Map all elements into the object key method and set the value
-	my ($key, $ix, $value);
+        # Map all elements into the object key method and set the value
+        my ($key, $ix, $value);
 
-	# Parse DNSSEC stuff, if present
-	if (($key,$value) = $line =~ m/^(DNSSEC)\.+:\s*(.+)$/) {
-	    $self->{dnssec}->{$key} = $value;
+        # Parse DNSSEC stuff, if present
+        if (($key,$value) = $line =~ m/^(DNSSEC)\.+:\s*(.+)$/) {
+            $self->{dnssec}->{$key} = $value;
 
-	} elsif (($key, $ix, $value) = $line =~ m/^(DS Key Tag|Algorithm|Digest Type|Digest|Key Flags|Key Protocol|Key Algorithm|Key Public)\s+(\d+)\.+:\s*(.+)$/) {
-	    # Translate all DNSSEC stuff to methods
+        } elsif (($key, $ix, $value) = $line =~ m/^(DS Key Tag|Algorithm|Digest Type|Digest|Key Flags|Key Protocol|Key Algorithm|Key Public)\s+(\d+)\.+:\s*(.+)$/) {
+            # Translate all DNSSEC stuff to methods
             # replace spaces and - with _ for accessors.
 
             $key =~ y/ -/_/;
-	    # multiple '_' are collapsed to one '_'
-	    $key =~ s/_+/_/g;
+            # multiple '_' are collapsed to one '_'
+            $key =~ s/_+/_/g;
             $key = lc($key);
             $self->{dnssec}->{$ix}->{$key} = 
                 ($self->{dnssec}->{$ix}->{$key} ? $self->{dnssec}->{$ix}->{$key}."\n$value" : $value);
 
-	    #print STDERR "DNSSEC parse self: $key , $ix, $value\n--\n";
+            #print STDERR "DNSSEC parse self: $key , $ix, $value\n--\n";
 
-	} elsif (($key,$value) = $line =~ m/^(\w+[^.]+)\.{2,}\:\s*(.+)$/) {
+        } elsif (($key,$value) = $line =~ m/^(\w+[^.]+)\.{2,}\:\s*(.+)$/) {
             # replace spaces and - with _ for accessors.
             $key =~ y/ -/_/;
             $key = lc($key);
             $self->{$key} = 
                 ($self->{$key} ? $self->{$key}."\n$value" : $value);
 
-	} elsif (($key,$value) = $line =~ m/^(Created|Last updated):\s*(.+)$/) {
-	    $key =~ y/ -/_/;
-	    $key = lc($key);
-	    $self->{$key} = 
-		($self->{$key} ? $self->{$key}."\n$value" : $value);
+        } elsif (($key,$value) = $line =~ m/^(Created|Last updated):\s*(.+)$/) {
+            $key =~ y/ -/_/;
+            $key = lc($key);
+            $self->{$key} = 
+                ($self->{$key} ? $self->{$key}."\n$value" : $value);
 
-	} elsif (($key,$value) = $line =~ m/^(% )(.+)$/) {
+        } elsif (($key,$value) = $line =~ m/^(% )(.+)$/) {
 
-	    if ($value =~ m/(No match)$/) {
-		$self->{errno} = $WHOIS_LOOKUP_ERR_NO_MATCH;
+            if ($value =~ m/(No match)$/) {
+                $self->{errno} = $WHOIS_LOOKUP_ERR_NO_MATCH;
 
-	    } elsif ($value =~ m/(Quota exceeded)$/) {
-		$self->{errno} = $WHOIS_LOOKUP_ERR_QUOTA_EXCEEDED;
+            } elsif ($value =~ m/(Quota exceeded)$/) {
+                $self->{errno} = $WHOIS_LOOKUP_ERR_QUOTA_EXCEEDED;
 
-	    } elsif ($value =~ m/(Access denied)$/) {
-		$self->{errno} = $WHOIS_LOOKUP_ERR_NO_ACCESS;
+            } elsif ($value =~ m/(Access denied)$/) {
+                $self->{errno} = $WHOIS_LOOKUP_ERR_NO_ACCESS;
 
-	    } elsif ($value =~ m/(Referral denied)$/) {
-		$self->{errno} = $WHOIS_LOOKUP_ERR_REFERRAL_DENIED;
+            } elsif ($value =~ m/(Referral denied)$/) {
+                $self->{errno} = $WHOIS_LOOKUP_ERR_REFERRAL_DENIED;
 
-	    } elsif ($value =~ m/(ERROR - )$/) {
-		# Details can be found in the raw_text
-		$self->{errno} = $WHOIS_LOOKUP_ERR_OTHER;
-		
-	    } else {
-		$key = 'copyright';
-		$self->{$key} =
-		    ($self->{$key} ? $self->{$key}."\n$value" : $value);
-	    }
-	}
+            } elsif ($value =~ m/(ERROR - )$/) {
+                # Details can be found in the raw_text
+                $self->{errno} = $WHOIS_LOOKUP_ERR_OTHER;
+                
+            } else {
+                $key = 'copyright';
+                $self->{$key} =
+                    ($self->{$key} ? $self->{$key}."\n$value" : $value);
+            }
+        }
     }
     $self->{raw_text} = $text;
 
@@ -234,10 +239,10 @@ sub TO_JSON {
     my $rh;
 
     if ($whois) {
-	foreach my $k (sort keys(%$whois)) {
-	    my $a = $whois->$k;
-	    $rh->{$k} = $whois->get($k);
-	}
+        foreach my $k (sort keys(%$whois)) {
+            my $a = $whois->$k;
+            $rh->{$k} = $whois->get($k);
+        }
     }
 
     #use Data::Dumper;
